@@ -10,6 +10,9 @@ pay_conf_create = '/v1/batchInput/merConf'
 pay_conf_query = '/v1/batchInput/merConf'
 pay_conf_modify = '/v1/batchInput/merResidentModify'
 
+profile_audit = '/v1/merProfile/merProfileForAudit'
+profile_picture = '/v1/merProfile/merProfilePicture'
+
 
 def __request_init(url, request_params):
     ApiRequest.base_url = adapay_merchant.base_url
